netapp_ontap.models.account_application API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.account_application`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AccountApplicationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AccountApplication object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `application: str GET POST PATCH`

    Applications

    Valid choices:

    - amqp
    - console
    - http
    - ontapi
    - service_processor
    - ssh
  `authentication_methods: List[str] GET POST PATCH`

    The authentication_methods field of the account_application.

  `is_ldap_fastbind: bool GET POST PATCH`

    Optional property that specifies the mode of authentication as LDAP Fastbind.

  `is_ns_switch_group: bool GET POST PATCH`

    Optional property that specifies whether the user is an LDAP or NIS group.

  `second_authentication_method: str GET POST PATCH`

    An optional additional authentication method for multi-factor authentication (MFA). This property is only supported for SSH (ssh) and Service Processor (service_processor) applications. It is ignored for all other applications. Time-based One-Time Passwords (TOTPs) are only supported with the authentication method password or public key. For the Service Processor (service_processor) application, none and publickey are the only supported enum values.

    Valid choices:

    - none
    - password
    - publickey
    - nsswitch
    - domain
    - totp